Revert "Added canMapHostMemory feature"

This reverts commit af4edd277f.
Este commit está contenido en:
Aditya Atluri
2016-03-05 13:08:57 -06:00
padre af4edd277f
commit 2ebbdd6ec5
Se han modificado 2 ficheros con 0 adiciones y 21 borrados
-1
Ver fichero
@@ -177,7 +177,6 @@ inline static hipError_t hipDeviceGetProperties(hipDeviceProp_t *p_prop, int dev
p_prop->l2CacheSize = cdprop.l2CacheSize ;
p_prop->maxThreadsPerMultiProcessor = cdprop.maxThreadsPerMultiProcessor ;
p_prop->computeMode = cdprop.computeMode ;
p_prop->canMapHostMemory = cdprop.canMapHostMemory;
// Same as clock-rate:
p_prop->clockInstructionRate = cdprop.clockRate;
-20
Ver fichero
@@ -1,20 +0,0 @@
#include<iostream>
#include"test_common.h"
__global__ void Add(hipLaunchParm lp, float *Ad, float *Bd, float *Cd){
int tx = hipThreadIdx_x + hipBlockIdx_x * hipBlockDim_x;
Cd[tx] = Ad[tx] + Bd[tx];
}
int main(){
float *A, *B, *C;
float *Ad, *Bd, *Cd;
hipDeviceProp_t prop;
int device;
hipGetDevice(&device);
hipDeviceGetProperties(&prop, device);
if(prop.canMapHostMemory != 1){
std::cout<<"Exiting.."<<std::endl;
}
}